import * as d3 from 'd3';

var width = 420,
  height = 340;

var data = {
  name: '1',
  children: [
    {
      name: '1.1',
      children: [
        {
          name: '1.1.1',
          size: 100,
        },
        {
          name: '1.1.2',
          size: 300,
        },
        {
          name: '1.1.3',
          children: [
            {
              name: '1.1.3.1',
              size: 200,
            },
            {
              name: '1.1.3.2',
              size: 200,
            },
            {
              name: '1.1.3.3',
              size: 400,
            },
          ],
        },
      ],
    },
    {
      name: '1.2',
      size: 300,
    },
  ],
};

var layouts = [
  'treemapBinary',
  'treemapDice',
  'treemapSlice',
  'treemapSliceDice',
  'treemapSquarify',
];

export const main = (container) => {
  // const width = container.clientWidth;
  // const height = container.clientHeight;

  const treemapLayout = d3
    .treemap()
    .size([800, 400])
    .padding(16);

  const rootNode = d3.hierarchy(data);
  rootNode.sum((d) => d.size);

  function enteringTreemap(d) {
    treemapLayout.tile(d3[d]);
    treemapLayout(rootNode);

    d3.select(this)
      .append('text')
      .text((d) => d)
      .attr('dy', 14);

    var nodes = d3
      .select(this)
      .append('g')
      .style('transform', `translate(0, 20)`)
      .selectAll('g')
      .data(rootNode.descendants())
      .join('g')
      .style(
        'transform',
        (d) => `translate(${d.x0}px, ${d.y0}px)`,
      );

    nodes
      .append('rect')
      .attr('width', (d) => d.x1 - d.x0)
      .attr('height', (d) => d.y1 - d.y0)
      .attr('fill', 'steelblue')
      .attr('opacity', 0.3)
      .attr('stroke', 'white');

    nodes
      .append('text')
      .attr('dx', 4)
      .attr('dy', 14)
      .text((d) => d.data.name)
      .style('font-family', 'Helvetica')
      .style('font-size', '12px')
      .style('fill', 'white');
  }

  const svg = d3
    .select(container)
    .selectAll('svg')
    .data(layouts)
    .join('svg')
    .attr('width', width + 'px')
    .attr('height', height + 'px')
    .each(enteringTreemap);
};
